server/test/data/migration/postcreate.py
changeset 1977 606923dff11b
parent 0 b97547f5f1fa
child 3363 d3736311d0c4
--- a/server/test/data/migration/postcreate.py	Thu May 28 08:06:12 2009 +0200
+++ b/server/test/data/migration/postcreate.py	Thu May 28 09:20:07 2009 +0200
@@ -1,4 +1,10 @@
-"""cubicweb post creation script, set note's workflow"""
+"""cubicweb post creation script, set note's workflow
+
+:organization: Logilab
+:copyright: 2001-2009 LOGILAB S.A. (Paris, FRANCE), license is LGPL v2.
+:contact: http://www.logilab.fr/ -- mailto:contact@logilab.fr
+:license: GNU Lesser General Public License, v2.1 - http://www.gnu.org/licenses
+"""
 
 todoeid = add_state(u'todo', 'Note', initial=True)
 doneeid = add_state(u'done', 'Note')